from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, Boolean, File, Int

Hiccorrelate_V0_1_0 = CommandToolBuilder(tool="hicCorrelate", base_command=["hicCorrelate"], inputs=[ToolInput(tag="in_matrices", input_type=Array(t=String(), optional=True), prefix="--matrices", doc=InputDocumentation(doc="Matrices to correlate (usually .h5 but other formats\nare allowed). hicCorrelate is better used on un-\ncorrected matrices in order to exclude any changes\nintroduced by the correction. (default: None)")), ToolInput(tag="in_zmin", input_type=String(optional=True), prefix="--zMin", doc=InputDocumentation(doc="Minimum value for the heatmap intensities. If not\nspecified the value is set automatically. (default:\nNone)")), ToolInput(tag="in_zmax", input_type=String(optional=True), prefix="--zMax", doc=InputDocumentation(doc="Maximum value for the heatmap intensities.If not\nspecified the value is set automatically. (default:\nNone)")), ToolInput(tag="in_colormap", input_type=Boolean(optional=True), prefix="--colorMap", doc=InputDocumentation(doc="Color map to use for the heatmap. Available values can\nbe seen here: http://matplotlib.org/examples/color/col\normaps_reference.html (default: jet)")), ToolInput(tag="in_plot_file_format", input_type=File(optional=True), prefix="--plotFileFormat", doc=InputDocumentation(doc="Image format type. If given, this option overrides the\nimage format based on the plotFile ending. The\navailable options are: png, emf, eps, pdf and svg.\n(default: None)")), ToolInput(tag="in_plot_numbers", input_type=Boolean(optional=True), prefix="--plotNumbers", doc=InputDocumentation(doc="If set, then the correlation number is plotted on top\nof the heatmap. (default: False)")), ToolInput(tag="in_method", input_type=String(optional=True), prefix="--method", doc=InputDocumentation(doc="Correlation method to use. (default: pearson)")), ToolInput(tag="in_logo_nep", input_type=Boolean(optional=True), prefix="--log1p", doc=InputDocumentation(doc="If set, then the log1p of the matrix values is used.\nThis parameter has no effect for Spearman correlations\nbut changes the output of Pearson correlation and, for\nthe scatter plot, if set, the visualization of the\nvalues is easier. (default: False)")), ToolInput(tag="in_labels", input_type=Int(optional=True), prefix="--labels", doc=InputDocumentation(doc="sample2 [sample1 sample2 ...], -l sample1 sample2 [sample1 sample2 ...]\nUser defined labels instead of default labels from\nfile names. Multiple labels have to be separated by\nspace, e.g. --labels sample1 sample2 sample3 (default:\nNone)")), ToolInput(tag="in_range", input_type=Int(optional=True), prefix="--range", doc=InputDocumentation(doc="In bp with the format low_range:high_range, for\nexample 1000000:2000000. If --range is given only\ncounts within this range are considered. The range\nshould be adjusted to the size of interacting domains\nin the genome you are working with. (default: None)")), ToolInput(tag="in_out_filename_heat_map", input_type=File(optional=True), prefix="--outFileNameHeatmap", doc=InputDocumentation(doc="File name to save the resulting heatmap plot.\n(default: None)")), ToolInput(tag="in_out_filename_scatter", input_type=File(optional=True), prefix="--outFileNameScatter", doc=InputDocumentation(doc="File name to save the resulting scatter plot.\n(default: None)")), ToolInput(tag="in_chromosomes", input_type=Array(t=String(), optional=True), prefix="--chromosomes", doc=InputDocumentation(doc="List of chromosomes to be included in the correlation.\n(default: None)")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads. Using the python multiprocessing\nmodule. Is only used with 'cool' matrix format. One\nmaster process which is used to read the input file\ninto the buffer and one process which is merging the\noutput bam files of the processes into one output bam\nfile. All other threads do the actual computation.\n(default: 4)"))], outputs=[ToolOutput(tag="out_out_filename_heat_map", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_filename_heat_map", type_hint=File()), doc=OutputDocumentation(doc="File name to save the resulting heatmap plot.\n(default: None)")), ToolOutput(tag="out_out_filename_scatter", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_filename_scatter", type_hint=File()), doc=OutputDocumentation(doc="File name to save the resulting scatter plot.\n(default: None)"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hiccorrelate_V0_1_0().translate("wdl", allow_empty_container=True)

